/*--------------------------------------------------------------------------+
$Id: DataDictionaryHandler.java 11307 2014-08-04 13:32:46Z teufl $
|                                                                          |
| Copyright 2011 ForTISS GmbH                     |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.kernel.ui.internal.handler;

import static org.fortiss.tooling.kernel.ui.ToolingKernelUIActivator.getImageDescriptor;

import java.util.Collections;
import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.eclipse.jface.resource.ImageDescriptor;
import org.fortiss.tooling.kernel.model.tutorial.TutorialDefinition;
import org.fortiss.tooling.kernel.ui.extension.IModelElementHandler;
import org.fortiss.tooling.kernel.ui.extension.base.ModelElementHandlerBase;

/**
 * {@link IModelElementHandler} for {@link TutorialDefinition}.
 * 
 * @author eder
 * @author $Author: teufl $
 * @version $Rev: 11307 $
 * @ConQAT.Rating GREEN Hash: FCF4A8026124D391128E28129C698161
 */
public final class TutorialDefinitionHandler extends ModelElementHandlerBase<TutorialDefinition> {

	/** Navigator view height. */
	private static final int NAVIGATOR_VIEW_HEIGHT = 0;

	/** {@inheritDoc} */
	@Override
	public String getName(TutorialDefinition element) {
		return "Tutorial";
	}

	/** {@inheritDoc} */
	@Override
	public String getDescription(TutorialDefinition element) {
		return element.getComment();
	}

	/** {@inheritDoc} */
	@Override
	public ImageDescriptor getIconImageDescriptor() {
		return getImageDescriptor("icons/tutorial.gif");
	}

	/** {@inheritDoc} */
	@Override
	public int getNavigatorViewWeight(TutorialDefinition element) {
		return NAVIGATOR_VIEW_HEIGHT;
	}

	/** {@inheritDoc} */
	@Override
	public List<EObject> getSubnodes(TutorialDefinition element) {
		return Collections.emptyList();
	}
}
